@@ -104,7 +104,6 @@ load_enc <- function(file, merge_id = "EMPI", sep = ":", id_length = "standard",
   DATA$enc_diag_group <- pretty_text(data_raw$DRG, remove_after = FALSE, remove_punc = FALSE, remove_white = FALSE)
   DATA$enc_enc_numb   <- pretty_text(data_raw$Encounter_number, remove_after = FALSE, remove_punc = FALSE, remove_white = FALSE)
 
-  DATA <- remove_column(dt = DATA, na = na, identical = identical)
-
+  if(dim(DATA)[1] != 1) {DATA <- remove_column(dt = DATA, na = na, identical = identical)}
   return(DATA)
 }
